slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSParallelType

Indicates the parallel mode that the direct solver will use

### Synopsis

    typedef enum { DS_PARALLEL_REDUNDANT,
                   DS_PARALLEL_SYNCHRONIZED,
                   DS_PARALLEL_DISTRIBUTED } DSParallelType;

### See Also

DSSetParallel()

### Level

advanced

### Location

include/slepcds.h
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages